/*
 *	Copyright (C) 2007. PARP Research Group.
 *	<http://perception.inf.um.es>
 *	University of Murcia, Spain.
 *
 *	This file is part of the QVision library.
 *
 *	QVision is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU Lesser General Public License as
 *	published by the Free Software Foundation, version 3 of the License.
 *
 *	QVision is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU Lesser General Public License for more details.
 *
 *	You should have received a copy of the GNU Lesser General Public
 *	License along with QVision. If not, see <http://www.gnu.org/licenses/>.
 */

/// @file qvcontour.h
/// @brief File from the QVision library.
/// @author PARP Research Group. University of Murcia, Spain.

#ifndef QVCONTOURS_H
#define QVCONTOURS_H

#include <qvdta/qvpolyline.h>

namespace qvdta
{
/// @brief Obtains a list of border pixels in a connected region of an image, by thresholding criteria.
///
/// This function gets the border subset of a <a href="http://en.wikipedia.org/wiki/Connected_set">connected set</a> of pixels in an image,
/// as a QVPolyline.
///
/// The condition to consider any pixel inside of the connected set will be that it's gray-scale value should be higher or equal than a given
/// threshold value, considering any pixel with a lesser gray-scale value outside the set.
/// 
/// @param image image from were to obtain the poly-line.
/// @param point any point inside the connected set.
/// @param threshold threshold to consider pixels inside or outside the connected set.
/// @returns a QVPolyline that follows the border set of the connected set.
/// @see getContoursThreshold
QVPolyline getContourThreshold(QVImage<uChar> &image, QPoint point, uChar threshold);

/// @brief Obtains a list of border \link QVPolyline poly-lines \endlink, for all connected sets in an image, following a thresholding criteria.
///
/// This function gets the border subsets of a <a href="http://en.wikipedia.org/wiki/Connected_set">connected set</a> of pixels in an image,
/// as a list of QVPolyline's.
///
/// The condition to consider any pixel inside of the connected set will be that it's gray-scale value should be higher or equal than a given
/// threshold value, considering any pixel with a lesser gray-scale value outside the set.
/// 
/// This function uses @ref getContourThreshold to get contours of the connected sets it finds in the picture.
///
/// @param image image from were to obtain the poly-lines.
/// @param threshold threshold to consider pixels inside or outside the connected sets.
/// @returns a QList of QVPolyline's that follows the border sets of the connected sets in the image.
/// @see getContourThreshold
//void getContoursThreshold(const QVImage <uChar> &image, const uChar threshold, QList<QVPolyline> &result);
QList<QVPolyline> getContoursThreshold(const QVImage <uChar> &image, const uChar threshold /*, QList<QVPolyline> &polylineList*/);
}

#endif

