/*
 *	Copyright (C) 2007. PARP Research Group.
 *	<http://perception.inf.um.es>
 *	University of Murcia, Spain.
 *
 *	This file is part of the QVision library.
 *
 *	QVision is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU Lesser General Public License as
 *	published by the Free Software Foundation, version 3 of the License.
 *
 *	QVision is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU Lesser General Public License for more details.
 *
 *	You should have received a copy of the GNU Lesser General Public
 *	License along with QVision. If not, see <http://www.gnu.org/licenses/>.
 */

/// @file qvisioninterface.h
/// @brief File from the QVision library.
/// @author PARP Research Group. University of Murcia, Spain.

#ifndef QVISIONINTERFACE_H
#define QVISIONINTERFACE_H

#include <QWidget>
#include <QMap>
#include <QCloseEvent>

#include <qvcore/qvapplication.h>
#include <qvcore/qvimage.h>
#include <qvgui/qvimagecanvas.h>
#include <qvgui/qvparamsinspectorwidget.h>
#include <qvgui/qvcamerawidgetsmall.h>
#include <qvgui/qvworkerinterfacesmall.h>
#include <ui/ui_qvisionform.h>

/// @file qvisioninterface.h
/// @brief QVisionInterface interface file.
/// @author PARP Group (http://perception.inf.um.es), Univ. of Murcia (Spain)

/// @class QVisionInterface qvparamsinspectorwidget.h qvgui/qvparamsinspectorwidget.h
/// @brief QVisionInterface class.
///
/// This class is a QWidget able to inspect and modify properties from a QVision object, managing QVCameras, and other QVPropertyHolders registered in the system, allowing the final user to modify some of their property values in real time, and to show QVImages resulting from the QVision's work, on the screen.
/// @ingroup qvgui
class QVisionInterface: public QWidget
{
	Q_OBJECT
public:	
	Ui::QVisionForm form;

	/// @brief Constructs a QVisionInterface object, given the QVision object which work (properties, result images, 
	/// etc...) will be inspected.
	/// @param name identifier for the object to be created.
	QVisionInterface(QWidget *parent = 0);
	~QVisionInterface();
	void closeEvent(QCloseEvent *event);

	/// @brief Adds controls for a QVCamera object to the interface, allowing the user to control and inspect the state of
	/// the camera.
	/// @param camera QVCamera object which will be controlled
	void add(QVCamera *camera);

	/// @brief Adds a new QVPropertyHolder, which double, integer and boolean properties will be added to the  interface to be
	/// controlled in real time by the final user
	/// the camera.
	/// @param name Identification name of the QVPropertyHolder in the interface
	/// @param object QVPropertyHolder object which property controls will be shown
	void add(QVWorker * worker);
	bool setVisible(QVWorker *worker,QString prop_orig);

signals:
	void closed();
		
private:
	QVBoxLayout* leftVBox;
	QList<QVImageCanvas*> qvimagecanvaslist;
};
#endif
