/*
 *	Copyright (C) 2007. PARP Research Group.
 *	<http://perception.inf.um.es>
 *	University of Murcia, Spain.
 *
 *	This file is part of the QVision library.
 *
 *	QVision is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU Lesser General Public License as
 *	published by the Free Software Foundation, version 3 of the License.
 *
 *	QVision is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU Lesser General Public License for more details.
 *
 *	You should have received a copy of the GNU Lesser General Public
 *	License along with QVision. If not, see <http://www.gnu.org/licenses/>.
 */

/// @file qvworkerinterfacesmall.h
/// @brief File from the QVision library.
/// @author PARP Research Group. University of Murcia, Spain.

#ifndef QVWORKERINTERFACESMALL_H
#define QVWORKERINTERFACESMALL_H

#include <qvcore/qvworker.h>

#ifdef PACKAGE_QWT
#include <qvgui/qvcpuplot.h>
#endif

#include <ui/ui_qvworkerformsmall.h>

/// \cond Not documented By now
/// @file qvworkerinterfacesmall.h
/// @brief QVWorkerInterfaceSmall interface file.
/// @author PARP Group (http://perception.inf.um.es), Univ. of Murcia (Spain)

/// @class QVWorkerInterfaceSmall qvparamsinspectorwidget.h qvgui/qvparamsinspectorwidget.h
/// @brief QVWorkerInterfaceSmall class.
///
/// This class is a QWidget able to inspect and modify properties from a QVWorker object, managing QVCameras, and other QVPropertyHolders registered in the system, allowing the final user to modify some of their property values in real time, and to show QVImages resulting from the QVWorker's work, on the screen.
/// @ingroup qvgui
class QVWorkerInterfaceSmall: public QWidget
{
	Q_OBJECT

public:	
	Ui::QVWorkerFormSmall form;

	/// @brief Constructs a QVWorkerInterfaceSmall object, given the QVWorker object which work (properties, result images, 
	/// etc...) will be inspected.
	/// @param name identifier for the object to be created.
	QVWorkerInterfaceSmall(QVWorker *worker, QWidget *parent = 0);

public slots:
	void newIterationSlot();
	void statusUpdate(QVWorker::TWorkerStatus status);
	
private:
	QVWorker *worker;
	#ifdef PACKAGE_QWT
	QVCpuPlot * cpuPlot, * cpuPlotSmall;
	#endif
	QWidget * leftLayout, * rightLayout;
	QVBoxLayout * leftVBox, * rightVBox;
};
/// \endcond Not documented By now
#endif // QDOUBLEPARAMWIDGETSMALL_H
